function [kvalmat]=gkansval(kpar)
%gkansval: Generate the kansei value matrix
%
%                            [kpar]=kanseiparam(i)
%
%          Where
%
%          kval: Is the kansei value matrix, where 
%                  the rows are the furnitures
%                  the columns are the kansei values
%
%          kpar: is the set of kansei parameters
%            i=0 : the number of the user types
%            i>0 : set of furniture numbers
%                  the rows are kansei identifiers
%                  1: Comfortable - Uncomfortable
%                  2: Handy/Practical - Impractical
%                  3: Complicated - Simple
%                  4: Picturesque - Harmonious
%                  5: Large - Tiny
%                  6: Heavy - Light
%                  7: Extravagant - Traditional
%                  8: Light colours - Dark colours
%                  9: Merry - Depressing
%                 10: Natural materials - Artifical materials
%                 11: Formal - Casual
%                 12: Modern - Antiquated
%                 13: Warm - Cold
%                 14: Friendly - Unfriendly
%                 15: Easy to handle - Difficult to handle
%                 16: Expensive - Cheap
%
%            The structure of the raws:
%                 Very first row identifier: 
%                       ordered furniture numbers, with alternating sign
%                       (same following sign means no ordering (same))
%                       0 (end symbol)
%                 First row identifier: 
%                       ordered furniture numbers, with alternating sign
%                       (same following sign means no ordering (same))
%                       0 (end symbol)
%                 A little bit first row identifier: 
%                       ordered furniture numbers, with alternating sign
%                       (same following sign means no ordering (same))
%                       0 (end symbol)
%                 Nor the first, nor the second row identifier: 
%                       ordered furniture numbers, with alternating sign
%                       (same following sign means no ordering (same))
%                       0 (end symbol)
%                 A little bit second row identifier: 
%                       ordered furniture numbers, with alternating sign
%                       (same following sign means no ordering (same))
%                       0 (end symbol)
%                 Second row identifier: 
%                       ordered furniture numbers, with alternating sign
%                       (same following sign means no ordering (same))
%                       0 (end symbol)
%                 Very second row identifier: 
%                       ordered furniture numbers, with alternating sign
%                       (same following sign means no ordering (same))
%

% Fuzzy Kansei Systems (furniture selection)
% By Szilveszter Kovacs
% e-mail: szkszilv@gold.uni-miskolc.hu
%   Copyright (c) by Szilveszter Kovacs

if nargin ~= 1,error('Invalid number of arguments!');end

[n,m] = size(kpar);  % n is the number of kansei identifiers
f = m-6;  % f is the number of the furnitures (6 pieces of separating 0)

sup = 1;  % max kansei value
inf = -1;  % min kansei value - not used
wr = (sup-inf)./7;  % 7 equal range: PL,PM,PS,Z,NS,NM,NL
for i=1:1:7
   range(i) = wr;
end;  % for

kvalmat = 2.*sup.*ones(f,n);  % initial value all element is 2*sup: invalid

for j=1 : 1 : n  % go through the kansei identifiers
   tkp = kpar(j,:);  % temp
   k = 1;  % range counter
   w = 0;  % last range last element
   wv = sup;  % max kansei value
   while w < m  % while we have new values
      i = 1;  % element counter
      di = 1;  % different element counter
      ws = -1;  % start previous sign negative (the first must be positive)
      while ((w+i)<=m & tkp(w+i)~=0)
         if sign(tkp(w+i)) ~= ws  % different sign, different object
            di = di+1;  % count the different elements
         end  % if
         ws = sign(tkp(w+i));  % new walue
         i = i+1;  % count the elements
      end  % while
      step = range(k)./di;  % di is the different element number + 1
      i = 1;  % element counter
      ws = -1;  % start previous sign negative (the first must be positive)
      while ((w+i)<=m & tkp(w+i)~=0)
         if sign(tkp(w+i)) ~= ws  % different sign, different object
            wv = wv-step;  % kansei value
         end  % if
         ws = sign(tkp(w+i));  % new walue
         if kvalmat(abs(tkp(w+i)),j) == 2.*sup
            kvalmat(abs(tkp(w+i)),j) = wv;  % store to the kansei value matrix
         else
            disp([abs(tkp(w+i)),j]);
            error('Elements multiply defined');
         end;  % if
         i = i+1;  % inc counter
      end  % while
      wv = wv-step;  % next kansei value bound
      k = k+1;  % next range
      w = w+i;  % next last element (0, if there are more)
   end  % while
end  % for j   
for j=1 : 1 : n  % go through the kansei identifiers
   for i=1 : 1 : f  % go through the furnitures
      if kvalmat(i,j) == 2.*sup
         error('There are elements not defined');
      end;  % if
   end  % for i
end  % for j   

