function [kpar]=kanspar(i)
%kanspar: Definition of the kansei parameter sets
%
%                            [kpar]=kanspar(i)
%
%          Where kpar is the set of kansei parameters
%          i is the user type identifier
%
%          kpar:
%            i=-2 : the vector of the kansei identifier enablers (1:enable, 0:disable)
%            i=-1 : the matrix of the names of the kansei identifiers
%            i=0 : the number of the user types
%            i>0 : set of furniture numbers
%                  the rows are kansei identifiers
%                  1: Comfortable - Uncomfortable
%                  2: Handy/Practical - Impractical
%                  3: Complicated - Simple
%                  4: Picturesque - Harmonious
%                  5: Large - Tiny
%                  6: Heavy - Light
%                  7: Extravagant - Traditional
%                  8: Light colours - Dark colours
%                  9: Merry - Depressing
%                 10: Natural materials - Artifical materials
%                 11: Formal - Casual
%                 12: Modern - Antiquated
%                 13: Warm - Cold
%                 14: Friendly - Unfriendly
%                 15: Easy to handle - Difficult to handle
%                 16: Expensive - Cheap
%
%            The structure of the raws:
%                 Very first row identifier: 
%                       ordered furniture numbers, with alternating sign
%                       (same following sign means no ordering (same))
%                       0 (end symbol)
%                 First row identifier: 
%                       ordered furniture numbers, with alternating sign
%                       (same following sign means no ordering (same))
%                       0 (end symbol)
%                 A little bit first row identifier: 
%                       ordered furniture numbers, with alternating sign
%                       (same following sign means no ordering (same))
%                       0 (end symbol)
%                 Nor the first, nor the second row identifier: 
%                       ordered furniture numbers, with alternating sign
%                       (same following sign means no ordering (same))
%                       0 (end symbol)
%                 A little bit second row identifier: 
%                       ordered furniture numbers, with alternating sign
%                       (same following sign means no ordering (same))
%                       0 (end symbol)
%                 Second row identifier: 
%                       ordered furniture numbers, with alternating sign
%                       (same following sign means no ordering (same))
%                       0 (end symbol)
%                 Very second row identifier: 
%                       ordered furniture numbers, with alternating sign
%                       (same following sign means no ordering (same))
%
%                 The alternating signs must be positive first always
%

% Fuzzy Kansei Systems (furniture selection)
% By Szilveszter Kovacs
% e-mail: szkszilv@gold.uni-miskolc.hu
%   Copyright (c) by Szilveszter Kovacs

if nargin ~= 1,error('Invalid number of arguments!');end

switch i
	case -2,
      kpar = [...	 % Enabling the kansei identifiers
        1;...
        1;...
        1;...
        1;...
        1;...
        1;...
        1;...
        1;...
        1;...
        1;...
        1;...
        1;...
        1;...
        1;...
        1;...
        0];
	case -1,
      kpar = [...	 % Names of the kansei identifiers
        'Comfortable      ';...
        'Practical        ';...
        'Complicated      ';...
        'Picturesque      ';...
        'Large            ';...
        'Heavy            ';...
        'Extravagant      ';...
        'Light Colours    ';...
        'Merry            ';...
        'Natural Materials';...
        'Formal           ';...
        'Modern           ';...
        'Warm             ';...
        'Friendly         ';...
        'Easy to Handle   ';...
        'Expensive        '];
	case 0,
      kpar=4;	% Number of the user types
	case 1,
      kpar(1,:)=[+11,-24,0,...
                 +7,-6,+36,0,...
                 +16,-12,+14,-35,+15,-22,+17,0,...
                 +25,-23,+13,-19,+21,-40,+3,-10,+1,-41,+37,0,...
                 +2,-43,+5,-4,+9,-8,+20,-34,0,...
                 +38,-27,+18,-33,+42,-39,+28,-26,0,...
                 +29,-30,+31,-32];
      kpar(2,:)=[+35,-37,+6,-36,0,...
                 +3,-30,+32,-31,+40,-10,+29,0,...
                 +24,-16,+39,-38,+27,-28,+26,-8,+2,-12,+22,-13,0,...
                 +9,-43,+1,-41,+17,-34,+11,-14,0,...
                 +7,-23,+19,-21,0,...
                 +5,-20,+25,-4,+15,0,...
                 +18,-33,+42];
      kpar(3,:)=[+35,-30,0,...
                 +42,-33,+43,-1,+17,-39,+10,-9,+6,-36,+3,-4,+40,0,...
                 +13,-25,+31,-32,+38,-19,+23,-11,+7,-37,0,...
                 +41,-34,+21,-18,0,...
                 +26,-27,+2,-12,+22,0,...
                 +29,-16,+24,-8,+20,-5,0,...
                 +28,-15,+14];
      kpar(4,:)=[0,...
                 +24,-33,+25,0,...
                 +1,+17,0,...
                 +13,+3,+19,+23,+28,+30,+31,+32,+7,+21,+40,0,...
                 +14,-16,+11,-15,+34,-41,0,...
                 +35,+39,+9,+10,+43,+8,+5,+29,+4,0,...
                 +37,+42,+6,+36,+38,+18,+22,+12,+2,+27,+26,+20];
      kpar(5,:)=[+29,-11,+7,-27,+26,+39,-16,+24,-42,+25,0,...
                 +32,-31,+28,-30,+20,-33,+5,-19,+23,-40,+21,-6,+36,0,...
                 +18,-35,+37,-38,+9,-10,+43,-1,+17,-13,+12,-2,+8,0,...
                 +3,-4,+15,-34,+41,-22,0,...
                 +14,0,...
                 0,...
                 ];
      kpar(6,:)=[+39,-11,+7,-42,+27,-26,+29,-18,+37,0,...
                 +31,-30,+32,-28,+35,-38,0,...
                 +16,-24,+25,-14,+15,-34,+4,-6,+36,-12,0,...
                 +33,-5,+20,-19,+23,-9,+10,-3,+8,-43,0,...
                 +21,-41,+17,-22,+1,0,...
                 +40,-13,+2,0,...
                 ];
      kpar(7,:)=[+25,-35,0,...
                 +24,-16,+20,-19,+23,-13,+21,-40,0,...
                 +4,-18,+5,-28,+3,-12,-36,-6,+30,+31,+32,0,...
                 +2,-8,+41,-26,+29,0,...
                 +14,-22,+15,-27,0,...
                 +34,-37,+38,+39,-7,-11,+9,+10,-17,-43,+1,0,...
                 +42,-33];
      kpar(8,:)=[+37,-15,+4,-8,+2,-14,+16,-11,0,...
                 +3,-24,+43,-13,+41,-30,+32,0,...
                 +31,-21,+7,0,...
                 +33,-23,+19,-1,+17,0,...
                 +29,-5,+10,-9,+28,-18,0,...
                 +40,-34,+25,-26,-39,-38,+27,0,...
                 +42,-20,+35,+6,+36,+12,+22];
      kpar(9,:)=[+24,-3,+16,-11,+1,-43,+37,-17,+41,0,...
                 +4,-2,+13,-8,+40,0,...
                 +33,-23,+19,-10,+14,-15,+21,-39,+38,0,...
                 +5,-28,+7,-29,+30,+31,+32,0,...
                 +27,+26,+12,+36,+6,0,...
                 +9,-25,+34,0,...
                 +22,-20,+35,-18,+42];
     kpar(10,:)=[0,...
                 1,2,3,4,5,7,8,9,10,11,...
                 13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,...
                 33,34,37,38,39,40,41,42,43,0,...
                 0,...
                 30,31,32,35,0,...
                 0,...
                 6,12,36,0,...
                 ];
     kpar(11,:)=[+42,-33,+15,0,...
                 +1,-17,+18,-22,+11,0,...
                 +19,-23,+25,-20,+24,-16,+6,-7,+37,0,...
                 +5,-21,+13,-36,+43,-35,0,...
                 +10,-9,+3,-12,+4,-34,+41,-2,0,...
                 +40,-39,+38,-30,-31,-32,0,...
                 +8,-14,+26,+27,+28,+29];
     kpar(12,:)=[+25,-20,+24,-16,+23,+19,-35,0,...
                 +13,-3,+4,-5,+8,-36,-6,-12,0,...
                 +21,-2,+28,-30,-31,-32,0,...
                 +40,-14,+26,0,...
                 +41,-34,+22,-15,+29,+27,0,...
                 +18,-17,+37,-9,-10,+11,-38,-39,+7,-43,+1,0,...
                 +42,-33];
     kpar(13,:)=[0,...
                 +11,0,...
                 +24,-6,+36,-12,+3,-9,+10,-16,+1,-43,0,...
                 +14,-15,+7,-17,+5,-41,+2,-8,0,...
                 +4,-34,+21,-22,+23,-19,+25,-20,+18,-35,0,...
                 +33,-40,+27,-26,0,...
                 +42,-28,+13,-37,+30,-32,+31,-39,+38,-29];
     kpar(14,:)=[+1,-43,+10,0,...
                 +11,-17,+41,-3,+40,-16,+24,-39,+38,-27,+37,0,...
                 +9,-8,+34,-21,+5,-2,0,...
                 +33,-14,+7,-15,0,...
                 +36,-6,+12,-13,+23,-19,0,...
                 +22,-4,+18,-35,0,...
                 +20,-25,+42,-28,+26,-29,+30,-32,+31];
     kpar(15,:)=[+37,-29,+28,-27,+38,-26,+39,0,...
                 +32,-31,+30,-9,+10,-2,+43,-20,0,...
                 +22,-12,+36,-6,+13,-5,+3,-8,+16,0,...
                 +4,-34,+17,-1,+41,-40,+21,-7,0,...
                 +18,-23,+19,-42,+14,0,...
                 +11,-24,+33,0,...
                 +25,-15,+35];
     kpar(16,:)=[0,...
                 0,...
                 0,...
                 1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,...
                 21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,...
                 41,42,43,0,...
                 0,...
                 0,...
                 ];
	case 2,
      kpar(1,:)=[+11,-6,0,...
                 +16,-24,+36,-17,+22,-41,+5,-12,+20,0,...
                 +14,-7,+15,-3,+2,-9,+33,-13,+42,0,...
                 +10,-43,+34,-1,+18,0,...
                 +35,-8,+28,-27,+38,0,...
                 +40,-21,+4,-39,+23,-19,+26,-25,0,...
                 +31,-37,+29,+30,-32];
      kpar(2,:)=[+6,-36,+26,-27,0,...
                 +22,-17,+41,-3,+10,-43,+28,0,...
                 +20,-38,+34,-5,+40,-9,0,...
                 +12,-8,+4,-1,+13,-2,+23,-37,0,...
                 +18,-33,+21,-42,+25,-14,+24,+11,0,...
                 +7,-35,+16,-15,+19,-39,+30,0,...
                 +29,-31,-32];
      kpar(3,:)=[+30,-31,+19,0,...
                 +37,-25,+35,-32,0,...
                 +39,-40,+38,-1,+26,-29,+7,0,...
                 +43,-42,+9,-3,+34,-21,+24,-16,+11,0,...
                 +4,-23,+10,-17,+33,-41,+2,0,...
                 +18,-6,-36,+15,-5,+13,-28,+27,-8,+22,-12,0,...
                 +20,-14];
      kpar(4,:)=[+11,-14,+17,0,...
                 +16,-15,+33,-43,0,...
                 +24,-42,+7,-31,+30,-4,+41,-25,+9,-18,+5,0,...
                 +1,-39,+35,-23,-19,+29,-37,+40,0,...
                 +38,-10,+3,-21,+28,-27,+8,0,...
                 +13,-26,+2,-20,0,...
                 +34,-32,+36,-6,+22,-12];
      kpar(5,:)=[+27,-26,+28,-7,0,...
                 +11,-16,+14,-39,+6,-35,0,...
                 +24,-5,+20,-36,+25,-38,+33,-1,+12,0,...
                 +4,-31,+42,-13,+23,-32,+37,0,...
                 +22,-9,+8,-2,+15,-40,+18,-17,+43,-41,+34,-30,0,...
                 +19,-21,+10,0,...
                 +29,-3];
      kpar(6,:)=[+26,-7,+11,-27,0,...
                 +35,-42,+30,-31,+28,-18,+32,0,...
                 +37,-14,+24,-16,+33,-17,+5,-29,0,...
                 +39,-25,+9,-21,+6,-36,+1,0,...
                 +20,-15,+41,-43,+23,-40,+13,-12,+3,0,...
                 +10,-38,+22,-34,+4,-19,+2,0,...
                 +8];
      kpar(7,:)=[+31,-12,0,...
                 +32,-30,+24,-16,+7,-25,0,...
                 +19,-13,+29,-15,+21,-18,+11,-14,+23,-33,+1,-28,0,...
                 +35,-9,+26,-17,+10,-2,0,...
                 +42,-39,+4,-40,+5,-3,+41,-34,0,...
                 +37,-20,+36,-6,+43,-8,0,...
                 +27,-22,+38];
      kpar(8,:)=[+37,-15,+32,-24,+30,0,...
                 +13,-4,+8,-14,+16,-31,0,...
                 +11,-2,+41,-43,+33,-23,+29,0,...
                 +3,-7,+21,-39,-1,+19,0,...
                 +28,-17,+5,-25,+34,-18,+10,-26,+9,-42,0,...
                 +27,-40,+38,-12,+35,0,...
                 +20,-22,+6,+36];
      kpar(9,:)=[+4,-2,+30,0,...
                 +8,-41,+13,-43,+24,-3,+11,-16,+33,-1,0,...
                 +15,-32,+28,-14,+29,-17,+7,-5,+38,-39,+9,0,...
                 +37,-31,+21,-23,+26,-25,0,...
                 +10,-19,+40,-27,+12,-36,-6,0,...
                 +34,-42,+18,-20,+22,0,...
                 +35];
     kpar(10,:)=[+8,-27,+4,-9,+1,0,...
                 +2,-18,+42,-33,+39,-38,0,...
                 +26,-34,+17,-16,+15,-11,0,...
                 +41,-22,+21,-40,+5,-43,0,...
                 +10,-14,+7,-28,+20,-25,+24,0,...
                 +3,-13,+37,-12,+36,-6,+23,-19,0,...
                 +35,-29,+31,+30,+32];
     kpar(11,:)=[+36,-6,+22,0,...
                 +33,-3,+17,0,...
                 +12,-35,+42,-27,+34,-28,+18,-20,0,...
                 +30,+31,+32,-29,+37,-26,+21,-15,0,...
                 +1,-7,+5,-10,+43,-41,+4,-8,+2,-13,0,...
                 +9,-39,+38,-25,+40,-11,+14,0,...
                 +19,+23,-16,+24];
     kpar(12,:)=[+30,-31,-32,+25,0,...
                 +35,-24,+37,-29,+6,-36,0,...
                 +12,-15,+19,+23,-11,+28,-13,+22,-40,0,...
                 +3,-16,+14,-8,+7,-34,+20,0,...
                 +2,-4,+5,-41,+1,-21,+33,-26,+18,-27,0,...
                 +43,-17,+10,-9,+42,0,...
                 +39,-38];
     kpar(13,:)=[+14,-33,0,...
                 +4,-16,+17,-15,+20,-11,+10,0,...
                 +24,-2,+41,-43,+5,-7,+6,-36,+9,-40,0,...
                 +8,-21,+42,-27,+26,-18,+28,-38,0,...
                 +3,-1,+13,-34,+25,-22,+39,-35,+29,0,...
                 +23,-19,+30,-37,0,...
                 +12,-31,+32];
     kpar(14,:)=[+11,-14,0,...
                 +39,-16,+27,-26,+8,0,...
                 +5,-2,+38,-7,+15,-10,+4,-17,+9,-34,+21,0,...
                 +3,-43,+1,-12,+41,-20,+6,-36,+22,-13,+40,-33,0,...
                 +24,-25,+42,-18,+23,-19,0,...
                 +28,-37,+30,0,...
                 +35,-29,+31,-32];
     kpar(15,:)=[+14,-38,0,...
                 +11,-27,+6,-36,+22,0,...
                 +5,-20,+12,-2,+43,-8,+1,-3,+9,-34,+37,0,...
                 +10,-7,+16,-24,+4,-15,+17,-41,0,...
                 +26,-39,+13,-33,+25,-18,+42,-21,+19,-30,0,...
                 +28,-40,+23,-35,+31,0,...
                 +29,-32];
     kpar(16,:)=[0,...
                 0,...
                 0,...
                 1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,...
                 21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,...
                 41,42,43,0,...
                 0,...
                 0,...
                 ];
	case 3,
      kpar(1,:)=[+11,-35,0,...
                 +24,-6,-21,+12,+36,-25,+22,0,...
                 +19,-42,+31,-32,+7,-14,0,...
                 +40,-16,+17,+34,-4,+33,-30,0,...
                 +20,-2,-3,+13,-10,-43,+8,-15,-18,-41,+23,0,...
                 +5,-1,-9,+27,-26,+28,0,...
                 +38,-39,+29,-37];
      kpar(2,:)=[+6,+12,-36,-22,0,...
                 +4,+16,-24,-40,+11,0,...
                 +19,+21,+17,-13,+23,+25,+41,-3,+2,-1,+20,0,...
                 +32,+31,-15,+8,-28,+27,-29,+5,+10,-34,0,...
                 +30,-37,+43,-33,+35,-39,0,...
                 +14,+7,-18,+42,0,...
                 +9,-38,+26];
      kpar(3,:)=[+35,-43,+30,-37,0,...
                 +42,-26,+38,+39,-33,-34,+31,0,...
                 +7,-1,-10,-25,-41,+21,+40,-9,-18,+32,0,...
                 +17,-2,-4,+19,-3,+5,+20,0,...
                 +11,-27,+23,-14,+13,+28,0,...
                 +16,+24,-8,+6,-15,+29,0,...
                 +36,-12,+22];
      kpar(4,:)=[0,...
                 +1,0,...
                 +17,+24,-14,-16,-41,+2,+4,+7,+8,-21,+22,0,...
                 +5,+25,+33,-11,-19,-23,-43,+18,+29,-20,-26,-28,-40,0,...
                 +15,+34,-10,+42,-12,-31,+30,+32,0,...
                 +9,-3,+27,+39,-35,-36,-38,+37,0,...
                 +6,-13];
      kpar(5,:)=[+26,-38,+7,+11,-18,0,...
                 +29,-27,-28,-39,+16,+24,-31,+25,+35,-5,-9,-21,0,...
                 +15,+20,+34,-17,-42,-43,+30,+33,+37,-14,-10,+22,0,...
                 +4,-6,+40,-1,-12,+8,-3,+23,0,...
                 +41,-36,+2,-19,0,...
                 +32,0,...
                 +13];
      kpar(6,:)=[+42,-11,+39,-26,-30,0,...
                 +31,+37,-7,+27,-28,0,...
                 +35,-18,-29,+16,+24,-15,-33,0,...
                 +32,+38,-6,-10,-17,+36,+40,-22,0,...
                 +14,+21,-34,+3,+43,-12,+41,+9,0,...
                 +1,+8,-13,-25,+19,+23,20,0,...
                 +5,-2,-4];
      kpar(7,:)=[+35,-11,+7,-18,0,...
                 +6,-16,+33,+42,-15,+34,-24,+14,0,...
                 +9,+21,-37,+10,+43,-30,-31,+36,+25,0,...
                 +5,-17,-41,+12,-32,0,...
                 +20,-40,+1,+22,-26,+39,-13,0,...
                 +3,+23,-2,-4,+8,+19,-28,0,...
                 +27,-38,+29];
      kpar(8,:)=[+37,-13,+15,-24,0,...
                 +8,+4,-2,-14,-16,+3,+41,-11,0,...
                 +43,-19,-23,+33,-5,+7,+18,-34,0,...
                 +1,-17,+9,-29,0,...
                 +21,-10,+27,+39,-28,0,...
                 +25,+31,-26,-42,+20,+38,-6,0,...
                 +30,-32,+12,+40,-22,-36,+35];
      kpar(9,:)=[+15,0,...
                 +18,-17,+43,0,...
                 +35,-7,-11,+21,-34,+25,0,...
                 +33,+42,-5,-10,+14,-22,0,...
                 +1,-41,+23,-6,+36,0,...
                 +20,-2,-9,+24,-12,-40,+4,+16,-8,-19,+3,0,...
                 +13,-28,+27,-30,-31,-32,+26,-38,-39,+37,-29];
     kpar(10,:)=[+42,-10,+1,+9,-41,0,...
                 +35,-4,+2,+5,+43,-33,-40,+8,+17,+22,0,...
                 +18,-20,-21,-34,+16,-7,-15,-24,0,...
                 +27,-11,+14,-6,-36,0,...
                 +26,-12,-19,-23,+3,-38,+28,-25,0,...
                 +39,-29,+13,0,...
                 +30,+31,+32,-37];
     kpar(11,:)=[+35,-18,+10,0,...
                 +11,+42,-9,-7,+15,+17,+33,-34,-43,0,...
                 +1,+4,+5,-14,-20,+41,-22,+25,-37,0,...
                 +21,-8,+40,-19,+12,+13,+23,0,...
                 +6,-36,+2,+3,+26,-38,+29,0,...
                 +27,-16,+24,-28,+39,0,...
                 +30,+31,+32];
     kpar(12,:)=[+30,-29,+31,+32,-13,+12,0,...
                 +3,-2,+19,+23,-6,-20,-36,+37,0,...
                 +14,-28,+25,-38,-40,+5,0,...
                 +16,-24,+15,-11,+22,+26,-39,0,...
                 +8,-4,-41,+9,+27,+34,-21,+7,-33,0,...
                 +1,+17,-43,+18,0,...
                 +10,-42,+35];
     kpar(13,:)=[+7,-24,+11,+14,-25,+40,-22,0,...
                 +15,+21,-33,+17,+34,+41,-6,+12,0,...
                 +4,-23,-36,+13,+18,+19,-2,+16,-9,0,...
                 +5,+42,-20,+3,-10,+8,0,...
                 +35,-31,+1,+26,+28,+43,0,...
                 +32,-30,+38,+39,-27,0,...
                 +29,-37];
     kpar(14,:)=[+14,-24,0,...
                 +16,-2,-3,-13,+36,-7,+11,+29,0,...
                 +5,+6,-23,+32,+39,0,...
                 +30,-20,+8,-19,-22,+9,0,...
                 +4,-12,+21,+25,+28,-31,+27,-10,-18,-42,+38,0,...
                 +40,-15,-26,+37,-17,-33,-41,+35,0,...
                 +34,-1,+43];
     kpar(15,:)=[+14,-19,+16,-8,0,...
                 +2,+4,-13,-20,-23,-34,+1,+22,-24,0,...
                 +3,+12,-5,-15,-25,-41,+9,+40,+43,0,...
                 +36,-6,+18,-10,-17,-33,+21,+29,-42,0,...
                 +28,-38,+27,-7,-11,0,...
                 +32,-31,+39,-26,0,...
                 +35,-30,+37];
     kpar(16,:)=[0,...
                 0,...
                 0,...
                 1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,...
                 21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,...
                 41,42,43,0,...
                 0,...
                 0,...
                 ];
	case 4,
      kpar(1,:)=[+7,-39,+38,-26,0,...
                 +40,-18,+25,-16,+21,-20,+27,0,...
                 +1,-9,+10,-24,+42,-2,0,...
                 +6,-22,+34,-19,-23,+3,-4,+30,-29,0,...
                 +17,-36,+35,-41,+8,-12,+37,-28,+43,0,...
                 +33,-5,+31,+32,-15,+11,0,...
                 +14,-13];
      kpar(2,:)=[+6,0,...
                 +22,-35,+1,-16,0,...
                 +34,-24,+40,-30,+36,-3,+10,-9,+2,-17,0,...
                 +23,-29,+31,+32,-12,+27,-38,+13,-7,+4,-8,-43,-41,+39,-18,0,...
                 +20,-21,+25,-11,+5,0,...
                 +19,-26,+14,0,...
                 +33,-42,+28,-37,+15];
      kpar(3,:)=[+19,-35,+25,-30,0,...
                 +24,-11,+23,-16,+33,-31,+32,-4,0,...
                 +39,-42,+21,-7,+40,-26,0,...
                 +6,+36,-9,+10,-17,+43,+1,-3,+38,-18,0,...
                 +5,-14,+28,-15,0,...
                 +37,-2,+8,-29,+12,-13,+41,0,...
                 +20,-34,+22,-27];
      kpar(4,:)=[+11,-19,+7,-28,+23,0,...
                 +25,-14,+24,-35,+33,-37,+30,-31,0,...
                 +18,-21,+26,-16,+32,-38,0,...
                 +15,-5,+1,-4,+41,-40,+6,-10,0,...
                 +42,-13,+17,-8,+3,0,...
                 +12,-20,+39,-27,0,...
                 +29,-43,+2,-36,+34,-9,+22];
      kpar(5,:)=[+11,-7,+26,-16,+27,-24,+28,-29,+39,0,...
                 +5,-14,+35,-31,0,...
                 +25,-19,+18,-20,+33,-40,+23,-6,+30,+32,0,...
                 +21,-42,+9,-37,+10,-17,+22,-12,+36,-2,+43,-3,0,...
                 +1,-4,+34,-13,+15,0,...
                 +41,-8,+38,0,...
                 ];
      kpar(6,:)=[+35,-18,+7,-11,0,...
                 +42,-33,+5,-30,+31,-28,+14,0,...
                 +21,-25,+16,-19,0,...
                 +6,-36,+9,-10,+17,-22,+34,0,...
                 +40,-32,+26,-23,+37,-27,+1,-38,+39,0,...
                 +20,-12,+24,-29,+4,-15,0,...
                 +13,-41,+43,-3,+8,-2];
      kpar(7,:)=[+11,-14,+35,0,...
                 +31,-32,+25,-28,+19,-24,0,...
                 +21,-18,+16,-23,+4,-20,+30,-3,+5,0,...
                 +2,-9,+6,+36,-12,+15,-13,0,...
                 +40,-8,+1,-17,+29,-41,+43,0,...
                 +10,-34,+37,-33,+26,-39,+38,0,...
                 +7,-27,+22,-42];
      kpar(8,:)=[+11,-24,+14,-8,+4,-2,+43,-41,+3,0,...
                 +16,-29,+1,-17,+18,0,...
                 +37,-15,+19,-21,+13,-23,0,...
                 +30,+32,+31,-33,+25,0,...
                 +7,-38,+39,-28,+9,-10,+5,0,...
                 +40,-34,+42,-27,+26,0,...
                 +22,-12,+20,-6,-36,+35];
      kpar(9,:)=[+11,-14,+16,-15,0,...
                 +33,-38,-32,+29,-7,+39,-5,+21,-31,0,...
                 +4,-24,-26,+37,-2,+43,-30,+23,-13,0,...
                 +3,-8,+17,-1,+41,-28,+27,-36,+35,0,...
                 +19,-9,+12,-40,+25,0,...
                 +10,-34,+6,-18,0,...
                 +42,-22,+20];
     kpar(10,:)=[+27,-26,+2,-9,+4,0,...
                 +21,-16,+38,-39,-10,+43,-34,+40,-7,+22,0,...
                 +8,-1,+41,-17,+42,0,...
                 +18,-25,-33,+14,0,...
                 +5,-20,+6,+36,-11,0,...
                 +15,-37,+12,-3,+24,-29,+28,0,...
                 +23,-19,+35,-13,+30,+31,+32];
     kpar(11,:)=[+22,0,...
                 +6,+36,-34,+3,0,...
                 +35,-9,+12,-10,+43,-33,0,...
                 +1,-17,+2,-41,+8,-4,+20,-5,+42,-23,0,...
                 +15,-13,+37,-19,+7,-18,+21,0,...
                 +11,-14,+16,-25,+24,-40,+28,0,...
                 +30,+31,+32,-27,+29,-26,+39,-38];
     kpar(12,:)=[+11,-25,0,...
                 +39,-18,+21,-3,+23,-9,0,...
                 +7,-10,+20,-35,+24,-12,+19,-16,+28,0,...
                 +2,-6,+36,-31,+32,0,...
                 +22,-38,+26,-30,+1,-17,0,...
                 +40,-15,+34,-42,+8,-29,+27,0,...
                 +41,-4,+43,-33,+37,-13,+5,-14];
     kpar(13,:)=[+11,-14,+33,0,...
                 +7,-16,+6,-24,+42,-9,+18,0,...
                 +21,-36,+25,-40,+1,0,...
                 +10,-17,+22,-27,0,...
                 +5,-35,+26,-39,+34,-30,+12,0,...
                 +3,-2,+43,-38,+4,-41,+8,-23,+20,-19,+15,0,...
                 +28,-31,+32,-13,+29,-37];
     kpar(14,:)=[+39,-27,+26,0,...
                 +7,-40,+16,-1,+38,0,...
                 +21,-24,+30,-20,+17,-22,+4,-31,+2,-8,0,...
                 +25,-10,+6,-9,+43,-15,0,...
                 +32,-3,+12,-34,+23,-19,+33,-28,0,...
                 +18,-42,+36,-35,+41,-29,+5,-13,0,...
                 +37,-14,+11];
     kpar(15,:)=[+22,-6,-36,+3,-2,0,...
                 +1,-12,+9,-43,+8,-38,+10,-40,0,...
                 +20,-34,+41,-21,+17,-15,+4,0,...
                 +18,-13,+19,+23,-14,0,...
                 +33,-35,+25,-42,+24,-39,0,...
                 +5,-16,+30,-31,+32,-29,0,...
                 +7,-11,+27,-26,+28,-37];
     kpar(16,:)=[0,...
                 0,...
                 0,...
                 1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,...
                 21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,...
                 41,42,43,0,...
                 0,...
                 0,...
                 ];
	otherwise,error('Invalid usertype number!');
end

   
